import { ClippingRenderContext, EdgeRenderingMode, HorizontalAlignment, type ITextMeasurer, LineJoin, type OxyColor, type OxyImage, type OxyRect, type OxySize, type ScreenPoint, VerticalAlignment } from 'oxyplot-js';
/**
 * Provides a render context for scalable vector graphics output.
 */
export declare class SvgRenderContext extends ClippingRenderContext {
    /**
     * The writer.
     */
    private readonly w;
    /**
     * Initializes a new instance of the SvgRenderContext class.
     * @param width The width.
     * @param height The height.
     * @param isDocument Create an SVG document if set to true.
     * @param textMeasurer The text measurer.
     * @param background The background.
     * @param useVerticalTextAlignmentWorkaround Whether to use the workaround for vertical text alignment.
     */
    constructor(width: number, height: number, isDocument: boolean, textMeasurer: ITextMeasurer, background: OxyColor, useVerticalTextAlignmentWorkaround?: boolean);
    /**
     * Gets or sets the text measurer.
     */
    textMeasurer: ITextMeasurer;
    /**
     * Gets or sets a value indicating whether to use a workaround for vertical text alignment to support renderers with limited support for the dominate-baseline attribute.
     */
    useVerticalTextAlignmentWorkaround: boolean;
    /**
     * Closes the svg writer.
     */
    close(): void;
    /**
     * Completes the svg element.
     */
    complete(): void;
    getXml(): string;
    /**
     * Draws an ellipse.
     * @param rect The rectangle.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     */
    drawEllipse(rect: OxyRect, fill: OxyColor, stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode): Promise<void>;
    /**
     * Draws a line.
     * @param points The points.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     * @param dashArray The dash array.
     * @param lineJoin The line join.
     */
    drawLine(points: ScreenPoint[], stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray: number[], lineJoin: LineJoin): Promise<void>;
    /**
     * Draws a polygon.
     * @param points The points.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     * @param dashArray The dash array.
     * @param lineJoin The line join.
     */
    drawPolygon(points: ScreenPoint[], fill: OxyColor, stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode, dashArray: number[], lineJoin: LineJoin): Promise<void>;
    /**
     * Draws a rectangle.
     * @param rect The rectangle.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The thickness.
     * @param edgeRenderingMode The edge rendering mode.
     */
    drawRectangle(rect: OxyRect, fill: OxyColor, stroke: OxyColor, thickness: number, edgeRenderingMode: EdgeRenderingMode): Promise<void>;
    /**
     * Draws the text.
     * @param p The position.
     * @param text The text.
     * @param c The color.
     * @param fontFamily The font family.
     * @param fontSize The font size.
     * @param fontWeight The font weight.
     * @param rotate The rotation angle.
     * @param halign The horizontal alignment.
     * @param valign The vertical alignment.
     * @param maxSize The maximum size.
     */
    drawText(p: ScreenPoint, text: string, c: OxyColor, fontFamily: string, fontSize: number, fontWeight: number, rotate: number, halign: HorizontalAlignment, valign: VerticalAlignment, maxSize?: OxySize): Promise<void>;
    /**
     * Flushes this instance.
     */
    flush(): void;
    /**
     * Measures the text.
     * @param text The text.
     * @param fontFamily The font family.
     * @param fontSize Size of the font.
     * @param fontWeight The font weight.
     * @returns The text size.
     */
    measureText(text: string, fontFamily: string | undefined, fontSize: number, fontWeight: number): OxySize;
    /**
     * Draws the specified portion of the specified OxyImage at the specified location and with the specified size.
     * @param source The source.
     * @param srcX The x-coordinate of the upper-left corner of the portion of the source image to draw.
     * @param srcY The y-coordinate of the upper-left corner of the portion of the source image to draw.
     * @param srcWidth Width of the portion of the source image to draw.
     * @param srcHeight Height of the portion of the source image to draw.
     * @param destX The x-coordinate of the upper-left corner of drawn image.
     * @param destY The y-coordinate of the upper-left corner of drawn image.
     * @param destWidth The width of the drawn image.
     * @param destHeight The height of the drawn image.
     * @param opacity The opacity.
     * @param interpolate Interpolate if set to true.
     */
    drawImage(source: OxyImage, srcX: number, srcY: number, srcWidth: number, srcHeight: number, destX: number, destY: number, destWidth: number, destHeight: number, opacity: number, interpolate: boolean): Promise<void>;
    protected disposed: boolean;
    /**
     * Releases unmanaged and - optionally - managed resources
     * @param disposing true to release both managed and unmanaged resources; false to release only unmanaged resources.
     */
    protected dispose(disposing: boolean): void;
    /**
     * Sets the clipping rectangle.
     * @param clippingRectangle The clipping rectangle.
     */
    protected setClip(clippingRectangle: OxyRect): void;
    /**
     * Resets the clipping rectangle.
     */
    protected resetClip(): void;
}
//# sourceMappingURL=SvgRenderContext.d.ts.map