import { EdgeRenderingMode, HorizontalAlignment, LineJoin, type OxyColor, OxyColorEx, type OxyImage, type ScreenPoint, VerticalAlignment } from 'oxyplot-js';
import { XmlWriterBase } from './XmlWriterBase';
/**
 * Represents a writer that provides easy generation of Scalable Vector Graphics files.
 */
export declare class SvgWriter extends XmlWriterBase {
    private endIsWritten;
    private clipPathNumber;
    isDocument: boolean;
    numberFormat: (n: number) => string;
    /**
     * Initializes a new instance of the SvgWriter class.
     * @param width The width (in user units).
     * @param height The height (in user units).
     * @param isDocument if set to true, the writer will write the xml headers (?xml and !DOCTYPE).
     */
    constructor(width: number, height: number, isDocument?: boolean);
    /**
     * Closes the svg document.
     */
    close(): void;
    /**
     * Writes the end of the document.
     */
    complete(): void;
    /**
     * Creates a style.
     * @param fill The fill color.
     * @param stroke The stroke color.
     * @param thickness The stroke thickness (in user units).
     * @param dashArray The line dash array.
     * @param lineJoin The line join type.
     * @returns A style string.
     */
    createStyle(fill: OxyColor, stroke: OxyColor, thickness: number, dashArray?: number[], lineJoin?: LineJoin): string;
    /**
     * Writes an ellipse.
     * @param x The x-coordinate of the center.
     * @param y The y-coordinate of the center.
     * @param width The width.
     * @param height The height.
     * @param style The style.
     * @param edgeRenderingMode The edge rendering mode.
     */
    writeEllipse(x: number, y: number, width: number, height: number, style: string, edgeRenderingMode: EdgeRenderingMode): void;
    /**
     * Sets a clipping rectangle.
     * @param x The x coordinate of the clipping rectangle.
     * @param y The y coordinate of the clipping rectangle.
     * @param width The width of the clipping rectangle.
     * @param height The height of the clipping rectangle.
     */
    beginClip(x: number, y: number, width: number, height: number): void;
    /**
     * Resets the clipping rectangle.
     */
    endClip(): void;
    /**
     * Writes a portion of the specified image.
     * @param srcX The x-coordinate of the upper-left corner of the portion of the source image to draw.
     * @param srcY The y-coordinate of the upper-left corner of the portion of the source image to draw.
     * @param srcWidth Width of the portion of the source image to draw.
     * @param srcHeight Height of the portion of the source image to draw.
     * @param destX The destination x-coordinate.
     * @param destY The destination y-coordinate.
     * @param destWidth Width of the destination rectangle.
     * @param destHeight Height of the destination rectangle.
     * @param image The image.
     * @param interpolate Interpolate if set to true.
     */
    writeImage(srcX: number, srcY: number, srcWidth: number, srcHeight: number, destX: number, destY: number, destWidth: number, destHeight: number, image: OxyImage, interpolate: boolean): void;
    /**
     * Writes the specified image.
     * @param x The x-coordinate.
     * @param y The y-coordinate.
     * @param width The width of the image.
     * @param height The height of the image.
     * @param image The image.
     * @param interpolate Interpolate if set to true.
     */
    writeImage2(x: number, y: number, width: number, height: number, image: OxyImage, interpolate: boolean): void;
    /**
     * Writes a line.
     * @param p1 The first point.
     * @param p2 The second point.
     * @param style The style.
     * @param edgeRenderingMode The edge rendering mode.
     */
    writeLine(p1: ScreenPoint, p2: ScreenPoint, style: string, edgeRenderingMode: EdgeRenderingMode): void;
    /**
     * Writes a polygon.
     * @param points The points.
     * @param style The style.
     * @param edgeRenderingMode The edge rendering mode.
     */
    writePolygon(points: ScreenPoint[], style: string, edgeRenderingMode: EdgeRenderingMode): void;
    /**
     * Writes a polyline.
     * @param pts The points.
     * @param style The style.
     * @param edgeRenderingMode The edge rendering mode.
     */
    writePolyline(pts: ScreenPoint[], style: string, edgeRenderingMode: EdgeRenderingMode): void;
    /**
     * Writes a rectangle.
     * @param x The x coordinate.
     * @param y The y coordinate.
     * @param width The width.
     * @param height The height.
     * @param style The style.
     * @param edgeRenderingMode The edge rendering mode.
     */
    writeRectangle(x: number, y: number, width: number, height: number, style: string, edgeRenderingMode: EdgeRenderingMode): void;
    /**
     * Writes text.
     * @param position The position.
     * @param text The text.
     * @param fill The text color.
     * @param fontFamily The font family.
     * @param fontSize The font size (in user units).
     * @param fontWeight The font weight.
     * @param rotate The rotation angle.
     * @param halign The horizontal alignment.
     * @param valign The vertical alignment.
     */
    writeText(position: ScreenPoint, text: string, fill: OxyColor, fontFamily?: string | null, fontSize?: number, fontWeight?: number, rotate?: number, halign?: HorizontalAlignment, valign?: VerticalAlignment): void;
    /**
     * Converts a color to a svg color string.
     * @param color The color.
     * @returns The color string.
     */
    protected colorToString(color: OxyColorEx): string;
    /**
     * Writes a double attribute.
     * @param name The name.
     * @param value The value.
     */
    protected writeAttributeNumberString(name: string, value: number): void;
    /**
     * Writes the edge rendering mode attribute if necessary.
     * @param edgeRenderingMode The edge rendering mode.
     */
    private writeEdgeRenderingModeAttribute;
    /**
     * Converts a value to a string or to the specified "auto" string if the value is NaN.
     * @param value The value.
     * @param auto The string to return if value is NaN.
     * @returns A string.
     */
    private getAutoValue;
    /**
     * Converts a list of points to a string.
     * @param points The points.
     * @returns A string.
     */
    private pointsToString;
    /**
     * Writes the header.
     * @param width The width.
     * @param height The height.
     */
    private writeHeader;
}
//# sourceMappingURL=SvgWriter.d.ts.map